1.1.1.2. nikola.plugins package — Nikola 8.1.3 documentation

# 1.1.1.2. nikola.plugins package

Plugins for Nikola.

## 1.1.1.2.1. Subpackages

- 1.1.1.2.1.1. nikola.plugins.command package
  - 1.1.1.2.1.1.1. Subpackages
    - 1.1.1.2.1.1.1.1. nikola.plugins.command.auto package
    - 1.1.1.2.1.1.1.2. nikola.plugins.command.rst2html package
  - 1.1.1.2.1.1.2. Submodules
  - 1.1.1.2.1.1.3. nikola.plugins.command.check module
  - 1.1.1.2.1.1.4. nikola.plugins.command.console module
  - 1.1.1.2.1.1.5. nikola.plugins.command.default_config module
  - 1.1.1.2.1.1.6. nikola.plugins.command.deploy module
  - 1.1.1.2.1.1.7. nikola.plugins.command.github_deploy module
  - 1.1.1.2.1.1.8. nikola.plugins.command.import_wordpress module
  - 1.1.1.2.1.1.9. nikola.plugins.command.init module
  - 1.1.1.2.1.1.10. nikola.plugins.command.new_page module
  - 1.1.1.2.1.1.11. nikola.plugins.command.new_post module
  - 1.1.1.2.1.1.12. nikola.plugins.command.orphans module
  - 1.1.1.2.1.1.13. nikola.plugins.command.plugin module
  - 1.1.1.2.1.1.14. nikola.plugins.command.serve module
  - 1.1.1.2.1.1.15. nikola.plugins.command.status module
  - 1.1.1.2.1.1.16. nikola.plugins.command.subtheme module
  - 1.1.1.2.1.1.17. nikola.plugins.command.theme module
  - 1.1.1.2.1.1.18. nikola.plugins.command.version module
- 1.1.1.2.1.2. nikola.plugins.compile package
  - 1.1.1.2.1.2.1. Subpackages
    - 1.1.1.2.1.2.1.1. nikola.plugins.compile.markdown package
      - 1.1.1.2.1.2.1.1.1. Submodules
      - 1.1.1.2.1.2.1.1.2. nikola.plugins.compile.markdown.mdx_gist module
      - 1.1.1.2.1.2.1.1.3. nikola.plugins.compile.markdown.mdx_nikola module
      - 1.1.1.2.1.2.1.1.4. nikola.plugins.compile.markdown.mdx_podcast module
    - 1.1.1.2.1.2.1.2. nikola.plugins.compile.rest package
      - 1.1.1.2.1.2.1.2.1. Submodules
      - 1.1.1.2.1.2.1.2.2. nikola.plugins.compile.rest.chart module
      - 1.1.1.2.1.2.1.2.3. nikola.plugins.compile.rest.doc module
      - 1.1.1.2.1.2.1.2.4. nikola.plugins.compile.rest.gist module
      - 1.1.1.2.1.2.1.2.5. nikola.plugins.compile.rest.listing module
      - 1.1.1.2.1.2.1.2.6. nikola.plugins.compile.rest.media module
      - 1.1.1.2.1.2.1.2.7. nikola.plugins.compile.rest.post_list module
      - 1.1.1.2.1.2.1.2.8. nikola.plugins.compile.rest.soundcloud module
      - 1.1.1.2.1.2.1.2.9. nikola.plugins.compile.rest.thumbnail module
      - 1.1.1.2.1.2.1.2.10. nikola.plugins.compile.rest.vimeo module
      - 1.1.1.2.1.2.1.2.11. nikola.plugins.compile.rest.youtube module
  - 1.1.1.2.1.2.2. Submodules
  - 1.1.1.2.1.2.3. nikola.plugins.compile.html module
  - 1.1.1.2.1.2.4. nikola.plugins.compile.ipynb module
  - 1.1.1.2.1.2.5. nikola.plugins.compile.pandoc module
  - 1.1.1.2.1.2.6. nikola.plugins.compile.php module
- 1.1.1.2.1.3. nikola.plugins.misc package
  - 1.1.1.2.1.3.1. Submodules
  - 1.1.1.2.1.3.2. nikola.plugins.misc.scan_posts module
  - 1.1.1.2.1.3.3. nikola.plugins.misc.taxonomies_classifier module
- 1.1.1.2.1.4. nikola.plugins.task package
  - 1.1.1.2.1.4.1. Submodules
  - 1.1.1.2.1.4.2. nikola.plugins.task.archive module
  - 1.1.1.2.1.4.3. nikola.plugins.task.authors module
  - 1.1.1.2.1.4.4. nikola.plugins.task.bundles module
  - 1.1.1.2.1.4.5. nikola.plugins.task.categories module
  - 1.1.1.2.1.4.6. nikola.plugins.task.copy_assets module
  - 1.1.1.2.1.4.7. nikola.plugins.task.copy_files module
  - 1.1.1.2.1.4.8. nikola.plugins.task.galleries module
  - 1.1.1.2.1.4.9. nikola.plugins.task.gzip module
  - 1.1.1.2.1.4.10. nikola.plugins.task.indexes module
  - 1.1.1.2.1.4.11. nikola.plugins.task.listings module
  - 1.1.1.2.1.4.12. nikola.plugins.task.page_index module
  - 1.1.1.2.1.4.13. nikola.plugins.task.pages module
  - 1.1.1.2.1.4.14. nikola.plugins.task.posts module
  - 1.1.1.2.1.4.15. nikola.plugins.task.redirect module
  - 1.1.1.2.1.4.16. nikola.plugins.task.robots module
  - 1.1.1.2.1.4.17. nikola.plugins.task.scale_images module
  - 1.1.1.2.1.4.18. nikola.plugins.task.sitemap module
  - 1.1.1.2.1.4.19. nikola.plugins.task.sources module
  - 1.1.1.2.1.4.20. nikola.plugins.task.tags module
  - 1.1.1.2.1.4.21. nikola.plugins.task.taxonomies module
- 1.1.1.2.1.5. nikola.plugins.template package
  - 1.1.1.2.1.5.1. Submodules
  - 1.1.1.2.1.5.2. nikola.plugins.template.jinja module
  - 1.1.1.2.1.5.3. nikola.plugins.template.mako module

## 1.1.1.2.2. Submodules

## 1.1.1.2.3. nikola.plugins.basic_import module

Mixin for importer plugins.

class nikola.plugins.basic_import.ImportMixin

  Bases: :class:`object`

  Mixin with common used methods.

  cmd_options = [{'name': 'output_folder', 'long': 'output-folder', 'short': 'o', 'default': 'new_site', 'help': 'Location to write imported content.'}]
  static configure_redirections(url_map, base_dir='')

    Configure redirections from an url_map.

  doc_purpose = 'import a dump from a different engine.'
  doc_usage = '[options] export_file'
  generate_base_site()

    Generate a base Nikola site.

  classmethod get_channel_from_file(filename)

    Get channel from XML file.

  get_configuration_output_path()

    Get path for the output configuration file.

  name = 'import_mixin'
  needs_config = False
  static populate_context(channel)

    Populate context with settings.

  classmethod transform_content(content)

    Transform content to a Nikola-friendly format.

  static write_configuration(filename, rendered_template)

    Write the configuration file.

  classmethod write_content(filename, content, rewrite_html=True)

    Write content to file.

  write_metadata(filename, title, slug, post_date, description, tags, **kwargs)

    Write metadata to meta file.

  classmethod write_post(filename, content, headers, compiler, rewrite_html=True)

    Ask the specified compiler to write the post to disk.

  static write_urlmap_csv(output_file, url_map)

    Write urlmap to csv file.

nikola.plugins.basic_import.replacer(dst)

  Replace links.